	//Class that handles rendering of the chart.
	function ChartManager(communicationsManager,chartDivName,chartType) {  
		this.communicationsManager=communicationsManager;
		this.chartDivName=chartDivName;
		this.chartType=chartType;
		this.chartDataArray=null;
		this.hiddenChartDataArray=[];
		this.jsonResponse=null;
		this.plot=null;
		this.currentChartDataIdSelected=null;
		this.resultBucketSize=0;
		this.chartName=null;
		this.showPoints=true;
		this.xAxisLabel='';
		this.yAxisLabel='';
		this.displayAxisLabels=false;
		this.markCurrentChartDataSel=false;
		
    	//Initialize event handlers for chart point click, tool tip etc.
    	this.initializeChartEventHandlers();
		
	}  
	
	ChartManager.prototype.setShowPoints = function(showPoints) {
		this.showPoints=showPoints;
    };

	ChartManager.prototype.setChartName = function(chartName) {
		this.chartName=chartName;
    }; 

    
	ChartManager.prototype.updateChartData = function(newChartDataArray,jsonResponse) {

		var newChartIdToChartDataMap=new Object();
		
    	$.each(newChartDataArray,function(i,chartData){
    		newChartIdToChartDataMap[chartData.metaData.chartInfoId]=chartData;
    	});
    	var chartManager=this;
    	
    	//Iterate over existing chart data, update the existing chart data, do not add any new ones.
    	//Maintain the hidden state if any.
    	//Update the chartIdToChartDataMap.
    	$.each(chartManager.chartDataArray,function(i,chartData){
    		if(chartData!=null && chartData.metaData.chartInfoId in newChartIdToChartDataMap)
    		{
    			var isHidden=false;
    			if(chartManager.chartDataArray[i].data==null)
    			{
    				isHidden=true;
    			}
    			
    			chartManager.chartDataArray[i]=newChartIdToChartDataMap[chartData.metaData.chartInfoId];
    			chartManager.chartIdToChartDataMap[chartData.metaData.chartInfoId]=newChartIdToChartDataMap[chartData.metaData.chartInfoId];
    			if(isHidden==true)
    			{
    				chartManager.hiddenChartDataArray[i]=chartManager.chartDataArray[i].data;
    				chartManager.chartDataArray[i].data=null;
    			}
    			
    		}
    	});

    	
    };
    
    
	ChartManager.prototype.setChartData = function(chartDataArray,jsonResponse) {  
    	this.chartDataArray=chartDataArray;
    	this.jsonResponse=jsonResponse;
		
    	this.chartIdToChartDataMap=new Object();
    	var chartManager=this;
    	$.each(this.chartDataArray,function(i,chartData){
    		chartManager.chartIdToChartDataMap[chartData.metaData.chartInfoId]=chartData;
    	});
    	
    };

    //Method used to set chart data state, based on state passed in the metadata.
	ChartManager.prototype.setChartDataState = function() {  
		var chartManager=this;
		var chartDataSelectedIndex=-1;
		$.each(this.chartDataArray,function(i,flotChartData){
			if(flotChartData.metaData.chartInfoHidden && flotChartData.metaData.chartInfoHidden!='false')
				{
					chartManager.hideSeries(flotChartData.metaData.chartInfoId);
				}
			else
				{
					chartDataSelectedIndex=i;
				}
		});
		
		if(this.chartDataArray.length>0 && chartDataSelectedIndex>-1)
		{
			var chartInfoId=this.chartDataArray[chartDataSelectedIndex].metaData.chartInfoId;
			chartManager.setCurrentChartDataIdSelected(chartInfoId);
		}
	}; 

	ChartManager.prototype.setCurrentChartDataIdSelected = function(currentChartDataIdSelected) {  
		if(!currentChartDataIdSelected || typeof currentChartDataIdSelected == 'undefined')
			{
				currentChartDataIdSelected=null;
			}
		
    	this.currentChartDataIdSelected=currentChartDataIdSelected;
    }; 
    
    
    
    //Method to plot chart based on existing data for chartDataArray.
    ChartManager.prototype.plotChart = function() {  

    	//Draw the chart.
    	this.drawChart();

    }; 

    //If a series is a subset of another series, the two series are aligned, if not no effort is made to align.
    ChartManager.prototype.drawChart=function()
    {
    	var chartManager=this;
    	var options=null;
    	var data=[];
    	
    	if(this.chartDataArray ==null || this.chartDataArray.length==0)
    	{
    		return;
    	}
    	
    	var indexForCurrentDataSelected=0;
    	
    	if(this.currentChartDataIdSelected!=null)
    	{
        	indexForCurrentDataSelected=this.getIndexForCartInfoId(this.currentChartDataIdSelected);
        	if(indexForCurrentDataSelected>=0)
        		{
            	this.resultBucketSize = parseInt(this.chartDataArray[indexForCurrentDataSelected].metaData.resultBucketSize);          		
        		}
  		
    	}
    	
    	//If a series is within another visible series, align the start dates.
   		data=this.getAlignedData(this.chartDataArray,indexForCurrentDataSelected);
  		
   		data=this.setAllowMoreDrilldown(this.chartDataArray,data);

   		if(this.markCurrentChartDataSel==true)
   		{
   			data=this.markCurrentChartDataSelected(this.chartDataArray,data,indexForCurrentDataSelected);	
   		}
   		
    	var labels=null;
    	if(data.longestVisibleSeriesIndex!=null)//If realigned data is of the CurrentChartDataSelected, use the labels for the longestVisibleSeries which was used for alignment.
    		{
    			labels=this.getLabelsForCurrentChart(this.chartDataArray,indexForCurrentDataSelected);
    		}
    	else
    		{
    			labels=this.getLabelsForCurrentChart(this.chartDataArray,indexForCurrentDataSelected);
    		}
    	
    		labels=this.removeLabelsForChartSize(labels);
    	
    		if(this.chartType=="line")
    		{
    		options={
    				grid : {
    					backgroundColor : {
    						colors : [ "#fff", "#fff" ]
    					},
    					hoverable : true,
    					clickable : true,
    					borderWidth : 0
    				},
    				series : {
    					lines : {
    						show : true,
    						fill:false,
    						fillColor: { colors: [{ opacity: 0.7 }, { opacity: 0.0}] }
    					},
    					points : {
    						show : this.showPoints,
	                        radius: 3,
	                        lineWidth: 2
    					}
    				},
    				xaxis : {
    					ticks : labels
    				},
    				selection:{
    					mode:'x'
    				}
    			};
    		}
    		
    		this.plot = $.plot($(this.chartDivName), data, options);
    		
    		//Specify the chart name on the chart.
    		if(this.chartName!=null)
    		{
    			$(this.chartDivName).append("<div class='chartNameOnChart'>"+this.chartName+"</div>");	
    		}
    		
      		this.yAxisLabel='';
      		this.xAxisLabel='';
       		if(this.displayAxisLabels==true && data.longestVisibleSeriesIndex!=null)//longestVisibleSeriesIndex!=null , this happens when there is no graph to display.
       		{
       			this.yAxisLabel=this.jsonResponse.chartDataList[indexForCurrentDataSelected].metaData.fieldDisplayName;
       	   		this.xAxisLabel=this.jsonResponse.chartDataList[indexForCurrentDataSelected].metaData.dateLabel;
        		$("<div class='xAxisLabel'></div>").text(this.xAxisLabel).appendTo(this.chartDivName);
        		$("<div class='yAxisLabel'></div>").text(this.yAxisLabel).appendTo(this.chartDivName);
       		}
    		
    };

    
   
   
    //Start range and endRange are the interval numbers on the chart, ex a chart with 80 intervals, select from 10 to 40
    //If noPlotselectedEvent is true, no plotslectedEvent is generated, if false event is generated.
    ChartManager.prototype.selectPlot=function(startRange,endRange,noPlotselectedEvent)
    {
    	
    	if(this.chartIdToChartDataMap[this.currentChartDataIdSelected].data.length>endRange)
    		 {
        	 var startLabel=this.chartIdToChartDataMap[this.currentChartDataIdSelected].data[startRange][0];
        	 var endLabel=this.chartIdToChartDataMap[this.currentChartDataIdSelected].data[endRange][0];

        	 this.plot.setSelection({
    				xaxis: {
    					from: startLabel,
    					to: endLabel
    				}
    			},noPlotselectedEvent);    		 
    		 }
    }
    
    
//Method handles selection of a range of values.
    ChartManager.prototype.handlePlotSelection=function()
    {
    	var chartManager=this;

    	return function(event,ranges)
    	{
    		var currentChartDataSelectedIndex=chartManager.getIndexForCartInfoId(chartManager.currentChartDataIdSelected);
    		if(chartManager.getIndexForVisibleChartData()>=0 && chartManager.chartDataArray.length>currentChartDataSelectedIndex)
			{
				var chartData=chartManager.chartIdToChartDataMap[chartManager.currentChartDataIdSelected];
				if(chartData.chartDataNodes.length>0)
				{
					var startDateOnFirstNode=chartData.chartDataNodes[0].startDate;
					
					var startDate=parseInt(ranges.xaxis.from.toFixed(1))+parseInt(startDateOnFirstNode);
					var endDate=parseInt(ranges.xaxis.to.toFixed(1))+parseInt(startDateOnFirstNode);
					//console.log(startDate+' '+endDate);
        			var requestCount=getURLParameterRequestCount();
        			requestCount+=1;
        			chartManager.communicationsManager.drillDown(startDate, endDate, chartManager.resultBucketSize,-1,currentChartDataSelectedIndex,requestCount);
        			
				}
				
			}
    	}
    };
    
    
    ChartManager.prototype.displayErrorMessage=function(message)
    {
    	var errorMessageDivName='errorMsg_'+this.chartDivName.substring(1);
    	$('#'+errorMessageDivName).remove();
    	$(this.chartDivName).append('<div id="'+errorMessageDivName+'">'+message+'</div>');
    };


    
    //Used to reduce the number of ticks on the chart x axis so that smaller charts have fewer ticks. (ex:- dashboard charts have fewer ticks).
    ChartManager.prototype.removeLabelsForChartSize=function(labels)
    {
    	var newLabels=[];
    	//Calculate the number of labels to skip based on the width of the div to display the chart.
    	var width=$(this.chartDivName).width();
    	var nthLabelToUse=0;
    	//
    	var labelWidth=100;
    	
    	if(labels.length>0)
    	{
    		
    		if(labels[0][1].length>20)
    			{
    				labelWidth=150;
    			}
    	}
    	
    	nthLabelToUse=labels.length/(width/labelWidth);
    	if(nthLabelToUse<1)
    	{
    		nthLabelToUse=1;
    	}
    	nthLabelToUse=Math.ceil(nthLabelToUse);
    	
    	for ( var int = 0; int < labels.length; int++) {
			
    		if(int%nthLabelToUse==0 && int!=0)
			{
				newLabels.push(labels[int]);
			}
		}
    	
    	return newLabels; 
    };
    
    //Method that adjusts the lables displayed on series that are shorter that the longest series to avoid bunching up of lables.
    ChartManager.prototype.getLabelsForCurrentChart=function(chartDataArray,indexForCurrentDataSelected)
    {
    	if(this.isAllDataInChartHidden() || this.isChartEmpty())
   		{
    			return [];
   		}
    	
    	var ratio=this.getMaxLengthToCurrentLengthRatio(this.chartDataArray,indexForCurrentDataSelected);
    	ratio=Math.ceil(ratio);
    	var labels=chartDataArray[indexForCurrentDataSelected].labels;
    	var newLabels=[];
    	for ( var int = 0; int < labels.length; int++) {
			
    		if(int%ratio==0)
    			{
    				newLabels.push(labels[int]);
    			}
    		else
    			{
    				//Setting this to an empty setting to an empty string seem to display an unwanted '0' at the beginning.
    				newLabels.push("x");
    			}
		}
    	
    	return newLabels;
    };
    
//Method that calculates the ratio of the length of the longest series to current series.
    ChartManager.prototype.getMaxLengthToCurrentLengthRatio=function(chartDataArray,indexForCurrentDataSelected)
    {
    	//Find longest date series.
    	var longestDateSeriesLength=0;
    	var longestVisibleSeriesIndex=this.getLongestVisibleSeriesIndex(chartDataArray);
    	
    	var longestSeriesStartDate=parseInt(chartDataArray[longestVisibleSeriesIndex].metaData.startDateMillis);
    	var longestSeriesEndDate=parseInt(chartDataArray[longestVisibleSeriesIndex].metaData.endDateMillis);
    	longestDateSeriesLength=longestSeriesEndDate-longestSeriesStartDate;
    	
		var currentSeriesStartDate=parseInt(chartDataArray[indexForCurrentDataSelected].metaData.startDateMillis);
		var currentSeriesEndDate=parseInt(chartDataArray[indexForCurrentDataSelected].metaData.endDateMillis);
		
		var currentSeriesLength=currentSeriesEndDate-currentSeriesStartDate;
		
		var ratio=longestDateSeriesLength/currentSeriesLength;
    	return ratio;
    };

    
    ChartManager.prototype.getLongestVisibleSeriesIndex=function(chartDataArray)
    {
    	//Find longest date series.
    	var longestDateSeriesLength=0;
    	var longestSeriesIndex=0;
    	for ( var int = 0; int < chartDataArray.length; int++) {
    		
    		//Make sure that chart series is not hidden, is hidden if data is null.
    		if(chartDataArray[int].data!=null)
    			{
	        		var startDate=parseInt(chartDataArray[int].metaData.startDateMillis);
	        		var endDate=parseInt(chartDataArray[int].metaData.endDateMillis);
	        		var dateSeriesLength=endDate-startDate;
	        		if(dateSeriesLength>longestDateSeriesLength)
	        			{
	        				longestDateSeriesLength=dateSeriesLength;
	        				longestSeriesIndex=int;
	        			}
    			}
    	}
    	return longestSeriesIndex;
    };
    
    
    ChartManager.prototype.getAlignedData=function(chartDataArray,indexForCurrentDataSelected)
    {
    	var longestVisibleSeriesIndex=this.getLongestVisibleSeriesIndex(chartDataArray);
    	var dataArray=[];
    	dataArray.longestVisibleSeriesIndex=null;
    	var longestSeriesStartDate=null;
    	var longestSeriesEndDate=null;
    	if(longestVisibleSeriesIndex!=null)
    		{
	        	longestSeriesStartDate=parseInt(chartDataArray[longestVisibleSeriesIndex].metaData.startDateMillis);
	        	longestSeriesEndDate=parseInt(chartDataArray[longestVisibleSeriesIndex].metaData.endDateMillis);
    		}
	        	for ( var int = 0; int < chartDataArray.length; int++) {
	        		//Make sure that chart series is not hidden, is hidden if data is null.
	        		if(chartDataArray[int].data!=null)
	        			{
	        				
	    	        		var startDate=parseInt(chartDataArray[int].metaData.startDateMillis);
	    	        		var endDate=parseInt(chartDataArray[int].metaData.endDateMillis);
	    	        		var data=[];
	    	        		if(longestSeriesStartDate!=null && longestSeriesEndDate!=null &&  startDate>=longestSeriesStartDate && endDate<=longestSeriesEndDate)
	    	        		{
	    	        				//Align data.
	    	        				var delta=startDate-longestSeriesStartDate;
	    	        				for ( var j = 0; j < chartDataArray[int].data.length; j++) {
	    	        					var dataCoordinates=[];
	    	        					dataCoordinates.push(chartDataArray[int].data[j][0]+delta);
	    	        					dataCoordinates.push(chartDataArray[int].data[j][1]);
	    	        					data.push(dataCoordinates);
	    	        				}
	    	        				//If the adjusted series is the current chartDataSelected, set the labels to the longest series.
	    	        				if(int==indexForCurrentDataSelected)
	    	        				{
	    	        					dataArray.longestVisibleSeriesIndex=longestVisibleSeriesIndex;
	    	        				}
	    	        		}
	    	        		else
	    	        		{
	
	    	        				for ( var j = 0; j < chartDataArray[int].data.length; j++) {
	    	        					var dataCoordinates=[];
	    	        					dataCoordinates.push(chartDataArray[int].data[j][0]);
	    	        					dataCoordinates.push(chartDataArray[int].data[j][1]);
	    	        					data.push(dataCoordinates);
	    	        				}
	
	    	        		}
	        				dataArray.push({data:data,color:chartDataArray[int].color});
	        			}
	        		else
	        			{
	        				dataArray.push({data:null,color:chartDataArray[int].color});
	        			}
	        	}
    	return dataArray;
    };


    
    ChartManager.prototype.markCurrentChartDataSelected=function(chartDataArray,data,indexForcurrentChartDataSelected)
    {
		//data[currentChartDataSelected].lines={fill:true};
    	data[indexForcurrentChartDataSelected].points={
//                radius: 3,
//                lineWidth: 2,
//    			fill: false,
//                fillColor: chartDataArray[currentChartDataSelected].color,
                symbol:'triangle'
    	};
    	return data;
    };

    
    ChartManager.prototype.setAllowMoreDrilldown=function(chartDataArray,data)
    {
	        	for ( var int = 0; int < chartDataArray.length; int++) {
	        		//Make sure that chart series is not hidden, is hidden if data is null.

	        				var resultCount=parseInt(chartDataArray[int].metaData.resultCount);
	        				if(resultCount<halfLogDataPageSizeConfig)
	        				{
	        					data[int].hoverable=true;
	        					data[int].clickable=false;
	        					data[int].points={show:false};
	        				}
	        				if(int==0)
	        				{
	        					data[int].lines={fill:false};
	        				}
	        	}
    	return data;
    };

    
    
    
    ChartManager.prototype.initializeChartEventHandlers = function()
    {
    	//Handle clicks on the chart.
    	$(this.chartDivName).bind("plotclick", this.plotClickHandler(this));
    	
    	//Handle display of tool tip on hover.
    	$(this.chartDivName).bind("plothover",this.toolTipDisplayHandler(this));
    	
    	$(this.chartDivName).bind("plotselected",this.handlePlotSelection());
    };
    
    //Method that handles click on the chart.
    ChartManager.prototype.plotClickHandler=function(chartManager)
    {
    	return function(event,pos,item)
    	{
        		if (item) {
        			chartManager.plot.highlight(item.series, item.datapoint);
        			var labelIndex = parseInt(item.dataIndex);
        			var chartDataIndex= parseInt(item.seriesIndex);
        			var endDate = chartManager.chartDataArray[chartDataIndex].chartDataNodes[labelIndex].endDate;
        			//endDate=endDate+chartManager.chartDataArray[0].resolutionInMilliseconds;// -No longer required after change that made end date to be 1 resolution ahead of what was before.
        			var startDate=chartManager.chartDataArray[chartDataIndex].chartDataNodes[labelIndex].startDate;
        			var dateDelta=item.datapoint[0];//Difference between the first date in the series and start date of the clicked node.
        			
        			var requestCount=getURLParameterRequestCount();
        			requestCount+=1;
        			chartManager.communicationsManager.drillDown(startDate, endDate, chartManager.resultBucketSize,dateDelta,chartDataIndex,requestCount);
        		}
    	};
    	
    	
    };
    
    
    //Method that handles click on the chart.
    ChartManager.prototype.toolTipDisplayHandler=function(chartManager)
    {
    	return function(event,pos,item)
    	{
    		var previousPoint=null;
				if (item) {
					if (previousPoint != item.dataIndex) {
						previousPoint = item.dataIndex;

						$("#tooltip").remove();
						var x = item.datapoint[0], y = item.datapoint[1];
						
						y=y.toFixed(2);
						var labelIndex = parseInt(item.dataIndex);
						var seriesIndex= parseInt(item.seriesIndex);
						var fieldDisplayName=chartManager.chartDataArray[seriesIndex].metaData.fieldDisplayName;
						var chartInfoLabel=chartManager.chartDataArray[seriesIndex].metaData.chartInfoLabel;
						if(typeof chartInfoLabel != 'undefined')
						{
							if(chartInfoLabel.length>24)
							{
								chartInfoLabel=chartInfoLabel.substring(0,24)+'...';
							}
							if(chartInfoLabel.length>0)
							{
								chartInfoLabel=chartInfoLabel+'<br/>';
							}
						}
						else
						{
							chartInfoLabel='';
						}

						var color=chartManager.chartDataArray[seriesIndex].metaData.resultDataColor;
						var toolTipContents=chartInfoLabel+chartManager.chartDataArray[seriesIndex].chartDataNodes[labelIndex].label +'<br/>'+fieldDisplayName+":" + y;
						chartManager.showTooltip(item.pageX, item.pageY,toolTipContents,color);
					}
				} else {

					$("#tooltip").remove();
					previousPoint = null;
				}
    	};
    	
    	
    };
    
    ChartManager.prototype.showTooltip =function(x, y, contents,color) {
		$('<div id="tooltip">' + contents + '</div>').css({
			position : 'absolute',
			'font-size': '120%',
			display : 'none',
			top : y + 5,
			left : x + 5,
			'background-color' : color,
			opacity : 0.80
		}).appendTo("body").fadeIn(200);
	}	;
	
	//Returns the index for the last visible chartData.(note the i--)
	ChartManager.prototype.getIndexForVisibleChartData = function ()
	{
		for ( var i = this.chartDataArray.length-1; i >=0 ; i--) {
			if(this.chartDataArray[i].data!=null)
				{
					return i;
				}
		}
		return -1;
	};
	
	//Returns the index for the last visible chartData with nonzero result.(note the i--)
	ChartManager.prototype.getIndexForVisibleChartDataWithNonZeroResult = function ()
	{
		for ( var i = this.chartDataArray.length-1; i >=0 ; i--) {
			if(this.chartDataArray[i].data!=null)
				{
					if(parseInt(this.chartDataArray[i].metaData.resultCount) > 0)
					{
							return i;
					}
					
				}
		}
		return -1;
	};
	
	
	ChartManager.prototype.hideSeries = function (chartInfoId)
	{
		var index=this.getIndexForCartInfoId(chartInfoId);
		this.hiddenChartDataArray[index]=this.chartDataArray[index].data;
		this.chartDataArray[index].data=null;
		
	};
	
	ChartManager.prototype.showSeries = function (chartInfoId)
	{
		var index=this.getIndexForCartInfoId(chartInfoId);
		this.chartDataArray[index].data=this.hiddenChartDataArray[index];
		this.hiddenChartDataArray[index]=null;
		
	};

	ChartManager.prototype.removeSeriesWithChartInfoId = function (chartInfoId)
	{
		var index=this.getIndexForCartInfoId(chartInfoId);
		delete this.chartIdToChartDataMap[chartInfoId];
		this.chartDataArray[index].data=null;
		this.hiddenChartDataArray[index]=null;
	};
	
	//Method to check if the chart is empty or not.
	ChartManager.prototype.isChartEmpty= function ()
	{
		for ( var i = 0; i < this.chartDataArray.length; i++) {
			
			if(this.chartDataArray[i].data!=null && this.chartDataArray[i].data!=undefined)
				{
					return false;
				}
		}
		//There should not be any hidden chart data.
		for ( var i = 0; i < this.hiddenChartDataArray.length; i++) {
			
			if(this.hiddenChartDataArray[i]!=null && this.hiddenChartDataArray[i]!=undefined)
				{
					return false;
				}
		}
		
		return true;
	};
	
	
	ChartManager.prototype.isChartDataHidden= function (chartInfoId)
	{
		var chartData=this.chartIdToChartDataMap[chartInfoId];
		if(typeof chartData != 'undefined')
		{
			if(chartData.data==null)
			{
				return true;
			}
		}
		return false;
	}

	
	ChartManager.prototype.getSearchablePageCount= function (chartInfoId)
	{
		var chartData=this.chartIdToChartDataMap[chartInfoId];
		if(typeof chartData != 'undefined')
		{
			return chartData.metaData.searchablePageCount;
		}
		return -1;
	}

	
	//Method to check if the chart is empty or not.
	ChartManager.prototype.isAllDataInChartHidden= function ()
	{
		
		for ( var i = 0; i < this.chartDataArray.length; i++) {
			
			if(this.chartDataArray[i].data!=null && this.chartDataArray[i].data!=undefined)
				{
					return false;
				}
		}
		
		for ( var i = 0; i < this.hiddenChartDataArray.length; i++) {
			
			if(this.hiddenChartDataArray[i]!=null && this.hiddenChartDataArray[i]!=undefined)
				{
					return true;
				}
		}
		return false;
	};
	

	
	ChartManager.prototype.getSeriesColorForChartInfoId = function (chartInfoId)
	{
		var seriesNumber=this.getIndexForCartInfoId(chartInfoId);
		return this.getSeriesColor(seriesNumber);
	};

	
	ChartManager.prototype.getSeriesColor = function (seriesNumber)
	{
		return this.chartDataArray[seriesNumber].color;
	};

	
	ChartManager.prototype.getIndexForCartInfoId= function (chartInfoId)
	{
	
		if(!chartInfoId in this.chartIdToChartDataMap)
		{
			return -1;
		}
		
		
		for ( var i = 0; i < this.chartDataArray.length; i++) {
			
			if(this.chartDataArray[i]!=null && typeof this.chartDataArray[i]!=undefined)
			{
				if(this.chartDataArray[i].metaData.chartInfoId==chartInfoId)
				{
					return i;
				}
			}
		}
		
		return -1;
	};

	
	ChartManager.prototype.getChartInfoIdForCurrentSeries=function ()
	{
		
		if(this.currentChartDataIdSelected!=null)
			{
				var index=this.getIndexForCartInfoId(this.currentChartDataIdSelected);
				if(index>=0)
				{
					return this.currentChartDataIdSelected;
				}			
			}

		return null;
	};
	
	ChartManager.prototype.getChartInfoId = function (index)
	{
		if(parseInt(index)==-1)
			{
				return -1;
			}
		return this.chartDataArray[index].metaData.chartInfoId;
	};
