//Manager class that takes care of refreshing data collections.
function DataCollectionManager(communicationsManager,eventListener)
{
	this.listener=eventListener;
	this.communicationsManager=communicationsManager;
}


DataCollectionManager.prototype.initialize=function ()
{
	var dataCollectionManager=this;
	//If element exists
	if($("#dataCollectionId").length != 0) {
		
		$("#dataCollectionId").change({dataCollectionManager:this},this.handleDataCollectionSelection);
	
	}

	//dataCollectionStateRefreshInterval is set in the dataCollectionList.jsp page. Configured in Configuration.properties.
	this.refreshDataCollection(this);
	this.refreshTasks(this);
	this.currentPage=1;
	//lastXDataCollections is set in the dataCollectionList.jsp page. Configured in Configuration.properties.
	this.maxEntriesPerPage= lastXDataCollections;
	this.loadDataCollectionsForPage(this.currentPage,this.maxEntriesPerPage,this);
	this.loadTasks();
	this.paginationInitialized=false;
	
	
	$('body').on('click','.tailDC',function(){
		var dataCollection=$(this).closest("div[class='dataCollection']");
		var dataCollectionId=dataCollection.attr('id');
		dataCollectionManager.communicationsManager.reDoSearchTailDataCollection(true,dataCollectionId,dataCollectionManager);
		
	});
		
	
};

DataCollectionManager.prototype.handleReDoSearchTailDataCollection=function ()
{
	return function(response)
	{

		if(response.error==true)
		{
			notifyUser("Error", response.errorMessage, 3000,true);				
		}
		else
		{
			window.location.href = "/";
		}
	};
};

DataCollectionManager.prototype.refreshDataCollection=function (dataCollectionManager)
{
	return function()
	{
		dataCollectionManager.communicationsManager.getDataCollectionsForPage(dataCollectionManager.currentPage,dataCollectionManager.maxEntriesPerPage,dataCollectionManager);
	};
};


DataCollectionManager.prototype.refreshTasks=function (dataCollectionManager)
{
	return function()
	{
		dataCollectionManager.loadTasks();
	};
};

DataCollectionManager.prototype.dataCollectionResponseHandler=function (dataCollections)
{
	$.each(dataCollections,function(index,dataCollection)
			{
				var spinnerHTML='';
				if(dataCollection.state!='COMPLETED')
					{
						spinnerHTML='<img class="smallSpinner" src="/images/spinner/spinner_small.gif"/>';
					}
				$('#entry'+dataCollection.id).html(dataCollection.entries+spinnerHTML);
				$('#state'+dataCollection.id).val(dataCollection.state);
			});
};

DataCollectionManager.prototype.handleDataCollectionSelection=function (eventData)
{
	var url='http://'+window.location.host+window.location.pathname+'?dataCollectionId='+$(this).val();
	window.location=url;
};

DataCollectionManager.prototype.loadDataCollectionsForPage=function (pageNumber,entriesPerPage)
{

	this.communicationsManager.getDataCollectionsForPage(pageNumber,entriesPerPage,this);

};

DataCollectionManager.prototype.loadTasks=function ()
{

	this.communicationsManager.loadTasks(this);

};

DataCollectionManager.prototype.handlePaginationClick=function (pageNumber)
{
	this.communicationsManager.getDataCollectionsForPage(pageNumber,this.maxEntriesPerPage,this);
	this.currentPage=pageNumber;

};


DataCollectionManager.prototype.getTasksResponseHandler=function (dataCollectionManager)
{
	
	return function(tasks)
	{
		var outputHTML='';
		
		if(tasks.length>0)
		{
			$('#taskListsHeading').show();	
		}
		else
		{
			$('#taskListsHeading').hide();
		}
		
		if(tasks.length>0)
			{
			outputHTML='<table class="tasksTable">'+
			'<thead><tr><th></th><th>Status</th><th>Processed</th><th></th></tr></thead>';
			
				$.each(tasks,function(index,task)
				{
					outputHTML=outputHTML+'<tr>'+
								'<td class="wrapword"><div class="taskName">'+task.taskName+'</div></td>'+
								'<td><div class="taskVal">'+task.taskState+'</div></td>'+
								'<td><div class="taskVal">'+task.entriesProcessed+'</div></td>'+
								'<td><a  href=""  class="cancelLink" value="'+task.taskId+'">cancel</a></td>'+
								'</tr>';
				});
			outputHTML=outputHTML+'</table>';
			
			$('.tasksTable').remove();
			$('#taskListsHeading').after(outputHTML);

			$('.cancelLink').button({
				icons : {
					primary : "ui-icon-circle-close"
					//primary : "ui-icon-gear"
				},
				text : false
			});
			
			$('.cancelLink').click(dataCollectionManager.handleCancelTaskClick(dataCollectionManager,dataCollectionManager.communicationsManager));


			}
		else
			{
				$('.tasksTable').remove();
			}
		

		setTimeout(dataCollectionManager.refreshTasks(dataCollectionManager),dataCollectionStateRefreshInterval);
		
	};
	
	


};

DataCollectionManager.prototype.handleCancelTaskResponse=function (dataCollectionManager)
{
	
	return function()
	{
		dataCollectionManager.loadTasks();
	};

};


DataCollectionManager.prototype.handleDataCollectionOpearationResponse=function (dataCollectionManager)
{
	
	return function(data)
	{
		if(data.error)
		{
			dataCollectionManager.listener.displayMessage(data.error,true,2000);
		}
		else
		{
			dataCollectionManager.listener.displayMessage(data.message,false,2000);
		}
	};

};


DataCollectionManager.prototype.handleCancelTaskClick=function (dataCollectionManager,communicationsManager)
{
	
	return function(event)
	{

		event.preventDefault();
		var deleteLink=this;
		$('<div></div>').appendTo('body')
	    .html('<div><h6>Are you sure?</h6></div>')
	    .dialog({
	        modal: true,
	        title: 'Confirmation Dialog',
	        zIndex: 10000,
	        autoOpen: true,
	        width: 'auto',
	        resizable: false,
	        buttons: {
	            Yes: function () {
	                $(this).dialog("close");
	        		var taskId=$(deleteLink).attr('value');
	        		communicationsManager.cancelTask(taskId,dataCollectionManager);
	            },
	            No: function () {
	                $(this).dialog("close");
	            }
	        },
	        close: function (event, ui) {
	            $(this).remove();
	        }
	    });
		
	};
	
};

//This is used to maintain information used later during selenium tests. If elements refresh at a fast rate like the data collections on a page, selenium remote 
//can be a bit in consistent.
DataCollectionManager.prototype.maintainDebugInformation=function (dataCollection)
{

	var debugInfoId=dataCollection.id+'_debug';
	if($('#'+debugInfoId).length==0)
	{
		$('#data_collection_list').prepend('<input type="hidden" id="'+debugInfoId+'" class="selDebugInfo" dcid="'+dataCollection.id+'" entries="'+dataCollection.entries+'" indexName="'+dataCollection.name+'" />');
	}
	else
	{
		$('#'+debugInfoId).attr('entries',dataCollection.entries);
	}
}

DataCollectionManager.prototype.dataCollectionPageResponseHandler=function (dataCollectionManager)
{
	
	return function(dataCollectionPage)
	{
		var dataCollections=dataCollectionPage.searchIndexJSONList;
		$('.dataCollection').remove();
		var outputHTML='';
		$.each(dataCollections,function(index,dataCollection)
		{

			//This is used to maintain information used later during selenium tests. If elements refresh at a fast rate like the data collections on a page, selenium remote 
			//can be a bit in consistent.
			dataCollectionManager.maintainDebugInformation(dataCollection);
			var busyIndicatorHTML='';
			var pausePlayHTML='';
			var pausedStatusHTML='';
			var tailHTML='';
			
			if(dataCollection.entries>0)
			{
				tailHTML='<span class="tailDC" title="Tail data"></span>';
			}
		
			
			if(dataCollection.displayActiveIcon==true)
				{
					busyIndicatorHTML='<img class="busyIndicator" src="/images/active.png"/>';
				}
			else
				{
					busyIndicatorHTML='<img class="busyIndicator" src="/images/inactive.png"/>';
				}
			
			console.log(dataCollection.state);

			if(dataCollection.state=='PAUSED')
			{
				
				pausePlayHTML='<span class="pause" value="'+dataCollection.id+'"/>';
				pausedStatusHTML='<span class="searchIndexLabel">Status</span><span class="searchIndexVal">Paused</span>';
			}
			else
			{
				pausePlayHTML='<span class="continue" value="'+dataCollection.id+'"/>';
				pausedStatusHTML='<span class="searchIndexLabel">Status</span><span class="searchIndexVal">Active</span>';
			}

			outputHTML=outputHTML+' <div id="'+dataCollection.id+'" class="dataCollection">'+
			'<div class="searchIndexInfoName"><span class="activeInactive">'+busyIndicatorHTML+
			'</span><span class="searchIndexName"><a class="dataCollectionLink" href="dataCollection.jsp?indexId='+dataCollection.id+'">'+dataCollection.name+'</a></span></div>'+
			'<div class="searchIndexInfoEntries">'+
			'<span class="searchIndexLabel">Feed</span><span class="searchIndexVal">'+dataCollection.currentLogEntriesQueuedRate+'/sec</span>'+
			'<span class="searchIndexLabel">Processed</span><span class="searchIndexVal">'+dataCollection.currentLogEntriesRetrievedRate+'/sec</span>'+
			'<span class="searchIndexLabel">Entries</span><span class="searchIndexVal selIdEntries">'+dataCollection.entries+'</span>'+pausedStatusHTML+pausePlayHTML+tailHTML+'</div>'+
			'</div>';
			
			//Note that class starting with selId is used for selenium tests.

		});
		
		$('#dataCollectionDetails').after(outputHTML);
		
		
		$('.pause').button({
			disabled:!adminUser,
			icons : {
				primary : "ui-icon-play"
				//primary : "ui-icon-gear"
			},
			text : false
			//label : "Activate Data Collection"
		}).click(function(){
			dataCollectionManager.communicationsManager.continueDataCollection($(this).attr('value'),dataCollectionManager);
		});

		$('.continue').button({
			disabled:!adminUser,
			icons : {
				primary : "ui-icon-pause"
				//primary : "ui-icon-gear"
			},
			text : false
			//label : "Pause Data Collection"
		}).click(function(){
			
			dataCollectionManager.communicationsManager.pauseDataCollection($(this).attr('value'),dataCollectionManager);
		});
		
		if(parseInt(dataCollectionPage.numPages)>1)
		{
			if(!dataCollectionManager.paginationInitialized)
				{
					$('#dataCollectionPagination').jqPagination({
						current_page:dataCollectionManager.currentPage,
						max_page:dataCollectionPage.numPages,
						paged: function(page) {
							dataCollectionManager.handlePaginationClick(page);
						}
					});		
					dataCollectionManager.paginationInitialized=true;
				}
			else
				{
					$('#dataCollectionPagination').jqPagination('option','current_page',dataCollectionManager.currentPage,true);
					$('#dataCollectionPagination').jqPagination('option','max_page',dataCollectionPage.numPages,true);
					$('#dataCollectionPagination').show();
				}
			
		}
		else
		{
			$('#dataCollectionPagination').hide();
		}
		
		setTimeout(dataCollectionManager.refreshDataCollection(dataCollectionManager),dataCollectionStateRefreshInterval);
	};
	


};




