	//Manager class that has responsibility of coordinating actions.
	 /**
	 * @author tingumr
	 *
	 */
	function DataManager()
	{
		this.communicationsManager=new CommunicationsManager();
		this.fileOparationsManager=new FileOparationsManager(this.communicationsManager);
		this.findPatternResultDialog=new FindPatternResultDialog(this.communicationsManager,this,1000);
		this.validateStartPatternDialog=new ValidateStartPatternDialog(this.communicationsManager,this);
		this.dataCollectionNameDialog=new DataCollectionNameDialog(this.communicationsManager,this);
		this.dataCollectionManager=new DataCollectionManager(this.communicationsManager,this);
		this.addNewDataCollectionDialog=new AddNewDataCollectionDialog(this.communicationsManager,this);
		this.generateSampleDataDialog=new GenerateSampleDataDialog(this);
		
		this.configureFieldForLogDialog=new ConfigureFieldForLogDialog(this.communicationsManager,this);
		
		var dialogOptions={
				modal: true,
				autoOpen:false
			};
		this.datePatternDialog=$('#date_pattern_dialog').dialog(dialogOptions);
		
		this.contactSupportForm=new ContactSupportForm(this,"_data");
		
		this.contactSupportConfig={
				displayHeading:true,
				displayFromBox:true
		};
		this.initialText='Subject:Help me with xyz. \n\nSuggestions,Questions,Report Bug etc\n\n\n\n\n\n\n\nPhone(Optional):';
		
	}
	

	DataManager.prototype.initialize=function ()
	{
	
		//adminUser variable is set in /common/staticIncludes_js.jsp
		$('#add_data_collection').button({disabled:!adminUser});
		$('#add_to_search').button({disabled:!adminUser});
		$('#gen_sample_data').button({disabled:!adminUser});
		$('#gen_sample_data_cust').button({disabled:!adminUser});
		
		
		var dataManager=this;
		$('#gen_sample_data').click(function(event){
			//All default parameters.
			dataManager.communicationsManager.addSampleDataToSearchEngine('','','','','','','',dataManager,'');
		});
		
		$('#gen_sample_data_cust').click(function(event){
			//All default parameters.
			dataManager.generateSampleDataDialog.showDialog();
		});
		
		this.validateStartPatternDialog.initialize();
		this.dataCollectionNameDialog.initialize();
		this.dataCollectionManager.initialize();
		this.fileOparationsManager.initialize();
		this.configureFieldForLogDialog.initialize();
		
		$('#add_data_collection').click(this.handleAddNewDataCollection(this));
		
		$('#add_to_search').click(DataManager.prototype.handleAddToSearch(this.communicationsManager,this.findPatternResultDialog));
		this.contactSupportForm.displayContactSupportForm('#contactSupportContainer', this.contactSupportConfig,null,this.initialText);
	};
	
	$(document).ready(function() {
		var dataManager=new DataManager();
		dataManager.initialize();
	});

	DataManager.prototype.handleAddNewDataCollection=function (dataManager)
	{
		return function()
		{
			dataManager.addNewDataCollectionDialog.showDialog();
		};
	};

	
	
	DataManager.prototype.handleAddToSearch=function (communicationsManager,findPatternResultDialog)
	{
		return function()
		{
			var selectedIds = $("#fileTree").jstree(true).get_bottom_checked(false);
			console.log(selectedIds);
			//If no files have been selected, do nothing.
			if(selectedIds.length==0)
			{
				notifyUser("Message", "No files selected.",3000, true);
				return;
			}
			communicationsManager.setTreeSelectionState(selectedIds);
			communicationsManager.findStartPatternForFiles(selectedIds);
			findPatternResultDialog.showDialog();
			findPatternResultDialog.loadFindStartPatternResultAfterTimeout();
		};
	};
	//Method called after the findPatternResultDialog has loaded all results.
	DataManager.prototype.findPatternResultCompletedEventHandler=function (findPatternResultHolderForVerification,resultData)
	{
		this.resultData=resultData;
		//Add getFinalPattern method to all holders.
		this.addGetFinalPatternMethodToAllHolders(resultData);
		//Add getPatternType method to all holders
		this.addPatternTypeMethodToAllHolders(resultData);
		
		this.validateStartPatternDialog.setFindStartPatternResultHolder(findPatternResultHolderForVerification);
		this.validateStartPatternDialog.showDialog();
	};



	
	DataManager.prototype.addGetFinalPatternMethodToAllHolders=function (resultData)
	{

		//Method returns the pattern in the order - custom pattern, auto assigned custom pattern, auto detected pattern.
		var getFinalPatternMethod=function ()
			{
			//	Here this refers to the object to which this method is assigned, in this case as seen below to the holder.
				//Check if there is a custom pattern.
				if(this.customPattern !=undefined && this.customPattern!=null)
					{
						return this.customPattern;
					}
				//Check if there is a auto assigned custom pattern.		
				if(this.autoAssignedCustomPattern !=undefined && this.autoAssignedCustomPattern!=null)
				{
					return this.autoAssignedCustomPattern;
				}
				//return auto detected pattern
				return this.pattern;
			};
		
		$.each(resultData.findStartPatternStateHolderList,function(index,holder)
				{
					holder["getFinalPattern"]=getFinalPatternMethod;
				});
	};
	
	DataManager.prototype.addPatternTypeMethodToAllHolders=function (resultData)
	{

		//Method returns the pattern type - autoAssigned,autoAssignedCustom,customPattern
		var getPatternTypeMethod=function ()
			{
				//Check if there is a custom pattern.
				if(this.customPattern !=undefined && this.customPattern!=null)
					{
						return 'customPattern';
					}
				//Check if there is a auto assigned custom pattern.		
				if(this.autoAssignedCustomPattern !=undefined && this.autoAssignedCustomPattern!=null)
				{
					return 'autoAssignedCustom';
				}
				//return auto detected pattern
				return 'autoAssigned';
			};
		
		$.each(resultData.findStartPatternStateHolderList,function(index,holder)
				{
					holder["getPatternType"]=getPatternTypeMethod;
				});
	};
	
	DataManager.prototype.handleValidateStartPatternDialogCompleteEvent=function (pattern,resultHolder)
	{
		this.setStartPatternOnHolder(pattern, resultHolder);
		this.dataCollectionNameDialog.renderResultData(this.resultData,this.dataCollectionNameDialog);
		this.dataCollectionNameDialog.showDialog();
	};
	//Handler for validate button click when the validate button on the data collection name is clicked.
	DataManager.prototype.handleValidateButtonClickEvent=function (holderIndex)
	{
		var resultHolder=this.resultData.findStartPatternStateHolderList[holderIndex];
		this.validateStartPatternDialog.setFindStartPatternResultHolder(resultHolder);
		this.validateStartPatternDialog.showDialog();
	};

	
	//Handler for validate button click when the validate button on the data collection name is clicked.
	DataManager.prototype.handleConfigureButtonClickEvent=function (holderIndex)
	{
		var statePatternHolder=this.resultData.findStartPatternStateHolderList[holderIndex];
		var newDataCollection=false;
		//Make sure that a existing data collection has been selected. If it is a new data collection, no need to load fields for it.
		if(statePatternHolder.dataCollectionInfo.newDataCollection && statePatternHolder.dataCollectionInfo.newDataCollection==true)
		{
			newDataCollection=true;
		}

		
		if(statePatternHolder.dataCollectionInfo.selectedId && newDataCollection==false) 
		{
				var dataCollectionId=statePatternHolder.dataCollectionInfo.selectedId;
				var dataCollectionName=statePatternHolder.dataCollectionValue;
				
				var fieldInfos=this.getCachedFieldInfos(dataCollectionId,dataCollectionName);
				//Field infos are in cache.
				if(fieldInfos)
				{
					this.handleConfigureButtonClickEventAfterFieldLoad(holderIndex);
				}
				else
				{
					//Explicitly load only if not present in cache.
					this.loadFieldsForDataCollection(dataCollectionId,holderIndex);	
				}
		}
		else
		{
			newDataCollection=true;
		}
		
		if(newDataCollection)
		{
			this.handleConfigureButtonClickEventAfterFieldLoad(holderIndex);
		}
	};
	
	
	//Method used to load the fields for a data collection
	DataManager.prototype.loadFieldsForDataCollection=function (dataCollectionId,holderIndex)
	{
		
		
		var dataCollectionIdArray=new Array();
		dataCollectionIdArray.push(dataCollectionId);
		this.communicationsManager.getDataCollectionInfoWithFields(dataCollectionIdArray, this, holderIndex);
	};
	
	//Handler method after fields have been loaded.
	DataManager.prototype.dataCollectionResponseHandler=function (holderIndex)
	{
		var dataManager=this;
		//Here this is only one data collection at a time.
		return function(dataCollections){
			
			$.each(dataCollections,function(index,dataCollection)
			{
				dataManager.resultData.findStartPatternStateHolderList[holderIndex].fieldInfos=dataCollection.fieldInfos;
				//Initialize the fieldInfo cache.
				if(!dataManager.resultData.cachedFieldInfos)
				{
					dataManager.resultData.cachedFieldInfos=new Array();
				}
				if(dataCollection.fieldInfos)
				{
					var cachedFieldInfo=new Object();
					cachedFieldInfo.dataCollectionId=dataCollection.id;
					cachedFieldInfo.dataCollectionName=dataCollection.name;
					cachedFieldInfo.fieldInfos=dataCollection.fieldInfos;
	 				dataManager.resultData.cachedFieldInfos.push(cachedFieldInfo);
				}
			});
			dataManager.handleConfigureButtonClickEventAfterFieldLoad(holderIndex);
		};

	};

	
	//Method called after the field info for the data collection has been loaded.
	DataManager.prototype.handleConfigureButtonClickEventAfterFieldLoad=function (holderIndex)
	{
		var statePatternHolder=this.resultData.findStartPatternStateHolderList[holderIndex];
		var dataCollectionId=statePatternHolder.dataCollectionInfo.selectedId;
		var dataCollectionName=statePatternHolder.dataCollectionValue;

		var fields=this.getMergedFieldsForStartPatterStateHolder(dataCollectionId, dataCollectionName,statePatternHolder);
		
		this.configureFieldForLogDialog.renderFields(fields,holderIndex);
		this.configureFieldForLogDialog.showDialog();
	};

	
	
	//Handler to take care of requests to add to search engine.
	DataManager.prototype.handleAddToSearchEngine=function ()
	{
		
		var holderDataArray=[];
		$.each(this.resultData.findStartPatternStateHolderList,function(i,holder)
				{
					var holderData=new Object();
					holderData["dataCollectionId"]=holder.dataCollectionInfo.selectedId;
					holderData["dataCollectionName"]=holder.dataCollectionInfo.inputValue;
					holderData["newDataCollection"]=holder.dataCollectionInfo.newDataCollection;
					//If this is a new dataCollection, then do not send id of an existing data collection.
					if(holder.dataCollectionInfo.newDataCollection==true)
					{
						holderData["dataCollectionId"]=null;
					}
					holderData["fileName"]=holder.filePath;
					holderData["pattern"]=holder.getFinalPattern();
					holderData["selected"]=holder.selected;
					holderData["patternType"]=holder.getPatternType();
					holderData.fieldInfos=holder.fieldInfos;
					holderDataArray.push(holderData);
				});
		//Send holder state to the server.
		this.communicationsManager.addToSearchEngine(holderDataArray);
	};
	
	//Handler for check box selection on the DataCollection Name page.
	DataManager.prototype.handleCheckBoxClick=function (holderIndex,selected)
	{
		this.resultData.findStartPatternStateHolderList[holderIndex].selected=selected;

	};
	
	DataManager.prototype.setPatternsOnResultData=function (patterns)
	{
		$.each(this.resultData.findStartPatternStateHolderList,function(i,holder)
				{
					var finalPatternForHolder=holder.getFinalPattern();
					if(finalPatternForHolder!=patterns[i])
						{
							holder.customPattern=patterns[i];
						}
					
				});
	};
	
	//Method that stores data collection state from the dataCollection dialog to the holder.
	DataManager.prototype.setDataCollectionValuesOnResultData=function (dataCollectionInfoValues)
	{
		$.each(this.resultData.findStartPatternStateHolderList,function(i,holder)
				{
					holder.dataCollectionValue=dataCollectionInfoValues[i].inputValue;
					holder["dataCollectionInfo"]=dataCollectionInfoValues[i];
				});
	};
	
	DataManager.prototype.setStartPatternOnHolder=function (newPattern,validateDialogResultHolder)
	{
		
	 
		var holderFinalPattern=validateDialogResultHolder.getFinalPattern();
		
		//Check if a custom pattern has been specified.
		if(newPattern!=holderFinalPattern)
			{
				validateDialogResultHolder.customPattern=newPattern;
				if(this.resultData!=undefined)
				{
				$.each(this.resultData.findStartPatternStateHolderList,function(index,holder)
						{
							//Check if there are holders which used the original pattern, if so assign new pattern for the holder.
							if(holder.pattern==validateDialogResultHolder.pattern)
								{
									holder.autoAssignedCustomPattern=newPattern;
								
								}
							
						});
				}
			}
		else
			{
				//No change in detected in final effective pattern
			
			}
	};

	
	
	
	DataManager.prototype.getCachedFieldInfos=function (dataCollectionId,dataCollectionName)
	{
		var infos=null;
		if(this.resultData.cachedFieldInfos)
			{
				var cachedFieldInfos=this.resultData.cachedFieldInfos;
				
				$.each(cachedFieldInfos,function(index,cachedFieldInfo)
						{
							if(cachedFieldInfo.dataCollectionId==dataCollectionId && cachedFieldInfo.dataCollectionName==dataCollectionName)
							{
								
								infos=cachedFieldInfo.fieldInfos;;
								return false;
							}
							
						});
			}
		
		return infos;
	};
	
	
	//Method called when the next button is clicked on the configureFieldForLog dialog
	DataManager.prototype.handleSaveFieldInfoEvent=function (fieldInfos,currentLogEntryIndex)
	{
		var startPatternStateHolder=this.resultData.findStartPatternStateHolderList[currentLogEntryIndex];
		var logFields=new Array();
		$.each(fieldInfos,function(index,fieldInfo)
		{
			if(fieldInfo.selected==true)
			{
				logFields.push(fieldInfo);
			}
			
		});
		startPatternStateHolder.fieldInfos=logFields;
		this.dataCollectionNameDialog.showDialog();
	};
	
	
	//Method called when dialog is closed.
	DataManager.prototype.handleConfigureDialogCloseEvent=function ()
	{
		this.dataCollectionNameDialog.showDialog();
	};
	
	//Method returns the merged list of fields by merging the saved fields for the data collection with the current fields for the statePatternHolder
	DataManager.prototype.getMergedFieldsForStartPatterStateHolder=function (dataCollectionId,dataCollectionName,statePatternHolder)
	{
		var mergedFieldInfos=new Array();
		if(statePatternHolder.fieldInfos)
		{
			$.each(statePatternHolder.fieldInfos,function(index,fieldInfo)
			{
				mergedFieldInfos.push(fieldInfo);
			});
			
		} 
		
		//If there are no existing fields defined for the patternState(log)
		if(mergedFieldInfos.length==0)
		{
			var newFieldInfos=this.getAllNewlyAddedFields();
			$.each(newFieldInfos,function(index,newFieldInfo)
					{
						mergedFieldInfos.push(newFieldInfo);
					});
		}
		
		//Merge the fieldInfos loaded for the dataCollection(via a http request and then cached) with existing fieldInfos for the statePatternHolder.
		//Merge needs to happen only if there are existing saved fields.
		if(mergedFieldInfos.length > 0)
		{
			if(dataCollectionId)
				{
				//By the time this method is called, any saved field for a data collection is already in the cache.
					var cfieldInfos=this.getCachedFieldInfos(dataCollectionId,dataCollectionName);
					var dataManager=this;
					if(cfieldInfos)
					{
						//CachedFieldInfo object has following properties- dataCollectionId,fieldInfos
						$.each(cfieldInfos,function(index,fieldInfo)
								{
									//Check if the field with id is already there in mergedFieldInfos, if not add.
									var matchingFieldInfo=dataManager.getFieldInfoWithId(mergedFieldInfos, fieldInfo.id);
									if(matchingFieldInfo==null){
													fieldInfo.selected=false;
													mergedFieldInfos.push(fieldInfo);
									}
									
								});
					}
				}

			return mergedFieldInfos;
			
		}
		else
		{
			return this.getCachedFieldInfos(dataCollectionId,dataCollectionName);	
		}
		
	}; 
	

	
	
	
	
	//Method return fieldInfo with id.
	DataManager.prototype.getFieldInfoWithId=function(fieldInfos,id)
	{
		var matchingFieldInfo=null;
		$.each(fieldInfos,function(index,fieldInfo)
				{
					if(fieldInfo.id)
					{
						if(fieldInfo.id==id)
							{
								matchingFieldInfo=fieldInfo;
								return false;
							}
					}
				});
		
		return matchingFieldInfo;
	};

	//Method return fieldInfo with id.
	DataManager.prototype.getAllNewlyAddedFields=function()
	{
		var newFields=new Array();
		var startPatternStates=this.resultData.findStartPatternStateHolderList;
		
		
		$.each(startPatternStates,function(index,startPatternState)
				{
				if(startPatternState.fieldInfos)
					{
						//Iterate through the fieldInfos in the startPatternState.
						$.each(startPatternState.fieldInfos,function(index2,fieldInfo)
						{
							var exists=false;
							//Check if field has already been added.
							$.each(newFields,function(index3,newFieldInfo){
								
								if(newFieldInfo.fieldName==fieldInfo.fieldName)
									{
										exists=true;
										return false;
									}
								
							});	
							
							if(exists==false && fieldInfo.id=='NEW')
							{
								newFields.push(fieldInfo);
							}
						});

					}

				});
		
		return newFields;
	};

	
	//Display error message for file operations.
	DataManager.prototype.displayMessage=function (message,error,fadeOutDelay)
	{
		var delay=4000;
		if(fadeOutDelay)
		{
				delay=fadeOutDelay;
		}
		
		if(error)
			{
				notifyUser("Message", message, 4000, true);
				//$('#dataMessages').html('<span id="error_message_datacol" class="error">'+message+'</span>');
			}
		else
			{
				notifyUser("Message", message, 4000, false);
				//$('#dataMessages').html('<span id="error_message_datacol" class="message">'+message+'</span>');
			}
		
		//$('#error_message_datacol').show().delay(delay).fadeOut();
	};


	//Handlers used for notification from contactSupportForm
	DataManager.prototype.handleValidationFailure=function(message)
	{
		notifyUser("Error", message, 3000,true);
	};

	//Handlers used for notification from contactSupportForm	
	DataManager.prototype.handleSendingMessageNotification=function(message)
	{
		notifyUser("Message", message, 3000,false);
	};

	//Handlers used for notification from contactSupportForm
	DataManager.prototype.handleMessageSentNotificationSuccess=function(message)
	{
		notifyUser("Message", message, 5000,false);
		this.contactSupportForm.displayContactSupportForm('#support_container1', this.configuration,null,this.initialText);
	};
	
	//Handle file operation
	DataManager.prototype.handleAddSampleDataToSearchEngineResponse=function(params)
	{
		notifyUser("Message", 'Request sent to generate sample data.', 2000,false);
	};
	