//Manager class that has responsibility for file operations.
function FileOparationsManager(communicationsManager)
{
	this.communicationsManager=communicationsManager;
}


FileOparationsManager.prototype.initialize=function ()
{
	//adminUser variable is set in /common/staticIncludes_js.jsp
	$('#delete_file').button({disabled:!adminUser});
	$('#create_folder').button({disabled:!adminUser});
	$('#rename_file').button({disabled:!adminUser});
	$('#upload_file_b').button({disabled:!adminUser});
	
	$('#delete_file').click(this.handleDeleteFile(this.communicationsManager,this));
	$('#create_folder').click(this.handleCreateFolder(this.communicationsManager,this));
	$('#rename_file').click(this.handleRenameFile(this.communicationsManager,this));
	$('#upload_file_b').click(this.handleUploadFile(this.communicationsManager,this));
	if(!adminUser)
	{
		$('.fileinput-button').css('visibility','hidden');	
	}
	$('.fileinput-button').click(function(){
		//notifyUser("Message", "Zip the files for faster upload.", 7000, false,'show');
	});
//	$("#fileTree").bind('rename.jstree',this.handleEventOnRename(this.communicationsManager));
//	$("#fileTree").bind('create.jstree',this.handleCreateFolderCompleteEvent(this.communicationsManager));
	
	$("#fileTree").bind('move_node.jstree',this.handleMoveEvent(this.communicationsManager));
	
	
	
	if(!adminUser)
		{
			$('#upload_files').css('visibility','hidden');	
			notifyUser("Message", 'Admin access required to make changes to data.', 6000, true);
		}
	
	
	
	//Bind the fileUploadDone event event to refresh file tree once file upload is complete.
	$("#fileupload").bind('fileuploaddone', this.handleFileUploadDone(this.communicationsManager,this));
	

    // Initialize the jQuery File Upload widget:
    $('#fileupload').fileupload({
        // Uncomment the following to send cross-domain cookies:
        //xhrFields: {withCredentials: true},
        autoUpload:true,
        sequentialUploads:true
    });

};


FileOparationsManager.prototype.handleFileUploadDone=function (communicationsManager,fileOperationsManager)
{
	return function(e,data)
	{
		var response=jQuery.parseJSON(data.jqXHR.responseText);
		
		
		if(response && response.files[0].error)
		{
			fileOperationsManager.displayMessage(response.files[0].error,true,20000);
		}
		
		$("#fileTree").jstree('refresh');
	};	
};



FileOparationsManager.prototype.handleDeleteFile=function (communicationsManager,fileOperationsManager)
{
	return function()
	{
		var selectedIds=fileOperationsManager.getSelectedIds();

		//If no files have been selected, do nothing.
		if(selectedIds.length==0)
		{
			fileOperationsManager.displayMessage("No files selected.",true);
			return;
		}
		else
		{
			communicationsManager.sendDeleteRequest(selectedIds,fileOperationsManager);
		}
	};	
};

FileOparationsManager.prototype.handleDeleteFileResponse=function ()
{
	var fileOperationsManager=this;
	return function(jsonResponse)
	{
		if(jsonResponse.error==false)
		{
			
			var deletedFileIds = jsonResponse.fileIdsDeleted;
			
			$.each(deletedFileIds,function(index,value)
					{
						$("#fileTree").jstree('delete_node',value);
					});
			
			if(jsonResponse.message)
				{
				fileOperationsManager.displayMessage(jsonResponse.message,true);
				}
			//fileOperationsManager.displayMessage("File deleted.",false);
		}
		else
		{
			if(jsonResponse.message)
			{
				fileOperationsManager.displayMessage(jsonResponse.message,true);
			}
			else
			{
				fileOperationsManager.displayMessage("Error deleting file, file might be in use.",true);	
			}
			
			
		}
		
	};
};

FileOparationsManager.prototype.handleCreateFolder=function (communicationsManager)
{
	var fileOperationsManager=this;
	return function(jsonResponse)
	{
		//	m.np.attr('type')=='folder' - Check to make sure that folder exists.		
		var selectedNodes = $("#fileTree").jstree('get_selected');
		var node=null;
		if(selectedNodes.length>0)
			{
				node=selectedNodes[0];
				var nodeType=$(node).attr('type');
				if(nodeType!='folder')
				{
					node=node.parentNode;
				}
				else
				{
					node=null;
				}
			
			}

		
			//If node value is null, node is created under the currently selected node.
			$("#fileTree").jstree('create_node',node,{ type : "default" },'last',fileOperationsManager.handleCreateFolderEvent(communicationsManager),true);
			
//			//Unselect all nodes.
//			var selectedNodes = $("#fileTree").jstree('get_selected');
//			$.each(selectedNodes,function(index,value)
//					{
//						$("#fileTree").jstree('uncheck_node',value);
//					});
			
		
	};
};

FileOparationsManager.prototype.handleMoveEvent=function (communicationsManager)
{
	var fileOperationsManager=this;
	return function(event,data)
	{
		var movedNodeIds=[];
		var newParentNodeId=data.parent;
		movedNodeIds.push(data.node.id);
		communicationsManager.sendMoveFileRequest(fileOperationsManager,movedNodeIds,newParentNodeId,data);
	};
};

//This method is called on receiving json response.
FileOparationsManager.prototype.handleMoveFileResponse=function (fileOperationsManager,movedNodeIds,parentNodeId,data)
{
	return function(jsonResponse)
	{
		if(jsonResponse.error==false)
		{
			
		}
		else
		{
			if(jsonResponse.message)
				{
					fileOperationsManager.displayMessage(jsonResponse.message,true);
				}
			else
				{
					fileOperationsManager.displayMessage("Error Moving File.",true);	
				}
			
			data.instance.refresh();
		}
		//Refresh the jstree after move.
		//$("#fileTree").jstree("refresh");
	};
};


//This event is fired as soon as a node is created.
FileOparationsManager.prototype.handleCreateFolderEvent=function (communicationsManager)
{
	return function(new_node)
	{
		var inst =$("#fileTree").jstree(true).get_node('/');
		inst.edit(new_node);
	};
	
};

//This event is fired after node creation is finished.
FileOparationsManager.prototype.handleCreateFolderCompleteEvent=function (communicationsManager)
{
	var fileOperationsManager=this;
	return function(event,data)
	{
		var name=data.rslt.name;
		var parentNode=data.rslt.parent;
		var parentId=$(parentNode).attr('id');
		if(parentId==undefined)
			{
				parentId='';
			}
		
		communicationsManager.sendCreateFolderRequest(fileOperationsManager,name,parentId,data);
	};
};

//Handle json response for create folder.
FileOparationsManager.prototype.handleCreateFolderResponse=function (data)
{
	var fileOperationsManager=this;
	return function(jsonResponse)
	{
		if(jsonResponse.error==false)
		{
			//Set the new folder id.
			$(data.rslt.obj).attr('id',jsonResponse.id);
		}
		else
		{
			var message='Error creating folder.';
			if(jsonResponse.id)
				{
					if(jsonResponse.fileToErrorMap[jsonResponse.id]=='ERROR_FOLDER_EXISTS')
						{
							message='Folder exists, if not visible, try refreshing page.';
						}
				}
			fileOperationsManager.displayMessage(message,true,4000);
			$("#fileTree").jstree('delete_node',data.rslt.obj);
			
		}
	};
};


FileOparationsManager.prototype.handleRenameFile=function (communicationsManager)
{
	var fileOperationsManager=this;
	return function()
	{
		var selectedIds=fileOperationsManager.getSelectedIds();

		//If no files have been selected, do nothing.
		if(selectedIds.length==0)
		{
			fileOperationsManager.displayMessage("No files selected.",true);
			return;
		}
		else
		{
			$("#fileTree").jstree('rename');
		}
		
	};
};
//Event called after user has renamed the node.
FileOparationsManager.prototype.handleEventOnRename=function (communicationsManager)
{
	var fileOperationsManager=this;
	return function(event,data)
	{
		
		//If the new name and old name are different.
		if(data.rslt.new_name!=data.rslt.old_name)
			{
				var id=data.rslt.obj.attr('id');
				var newName=data.rslt.new_name;
				communicationsManager.sendRenameRequest(id,fileOperationsManager,newName,data);
			}
	};
};

FileOparationsManager.prototype.handleRenameFileResponse=function (data)
{
	var fileOperationsManager=this;
	return function(jsonResponse)
	{
		if(jsonResponse.error==false)
		{
			//If successfully renamed, sent the new id.
			$(data.rslt.obj).attr('id',jsonResponse.id);
		}
		else
		{
			fileOperationsManager.displayMessage("Error renaming file.",true);
			//$("#fileTree").jstree('uncheck_node',data.rslt.obj);
			$("#fileTree").jstree('rename_node',data.rslt.obj,data.rslt.old_name);
			//Rollback problem - User had to unselect and select the node again in order for rename to work again.
			 //$.jstree.rollback(data.rlbk);
		}

		
	};
};


FileOparationsManager.prototype.handleUploadFile=function (communicationsManager)
{
	return function()
	{
	};
};

//Returns the selected ids in the file tree.
FileOparationsManager.prototype.getSelectedIds=function ()
{
	var selectedIds = $("#fileTree").jstree('get_selected');

	return selectedIds;
};

//Display error message for file operations.
FileOparationsManager.prototype.displayMessage=function (message,error,fadeOutDelay)
{
	var delay=4000;
	if(fadeOutDelay)
	{
			delay=fadeOutDelay;
	}
	
	if(error)
		{
			$('#fileMessages').html('<span id="error_message_file" class="error">'+message+'</span>');
		}
	else
		{
			$('#fileMessages').html('<span id="error_message_file" class="message">'+message+'</span>');
		}
	
	$('#error_message_file').show().delay(delay).fadeOut();
};
